from PyQt6.QtWidgets import QDialog, QVBoxLayout, QHBoxLayout, QPushButton, QFileDialog
from .code_editor import CodeEditor

class CodeEditorDialog(QDialog):
    def __init__(self, parent=None, project_path=None, file_path=None):
        super().__init__(parent)
        self.project_path = project_path
        self.file_path = file_path
        
        # Set up the dialog
        self.setWindowTitle("Code Editor")
        self.resize(800, 600)
        
        # Create layout
        layout = QVBoxLayout()
        self.setLayout(layout)
        
        # Create code editor
        self.code_editor = CodeEditor(self, project_path)
        layout.addWidget(self.code_editor)
        
        # Create button layout
        button_layout = QHBoxLayout()
        layout.addLayout(button_layout)
        
        # Create Save button
        self.save_button = QPushButton("Save")
        self.save_button.clicked.connect(self.save)
        button_layout.addWidget(self.save_button)
        
        # Create Close button
        self.close_button = QPushButton("Close")
        self.close_button.clicked.connect(self.close)
        button_layout.addWidget(self.close_button)
        
        # Load file if provided
        if file_path:
            self.code_editor.set_file(file_path)
            
    def save(self):
        """Save the current file"""
        if not self.file_path:
            self.file_path, _ = QFileDialog.getSaveFileName(
                self, "Save File", "", "Python Files (*.py);;All Files (*.*)")
            
        if self.file_path:
            self.code_editor.save_file(self.file_path)
            
    def get_code(self):
        """Get the current code content"""
        return self.code_editor.get_text() 